import QtQuick 2.0
import Ubuntu.Components 0.1
import Ubuntu.Components.Popups 0.1
import Ubuntu.Components.ListItems 0.1 as ListItem


/*!
    \brief MainView with Tabs element.
           First Tab has a single Label and
           second Tab has a single ToolbarAction.
*/

import "databasemodule.js" as DB

MainView {
    // objectName for functional testing purposes (autopilot-qt5)
    id: mainView
    objectName: "rssreader"
    applicationName: "ubuntu-rssreader-app"
    
    width: units.gu(50)
    height: units.gu(75)

    Component.onCompleted: {
//        PopupUtils.open(popoverComponent, mainView);
    }

//    Rectangle
//    {
//        id: test_demo
//        width: units.gu(10)
//        height: units.gu(7)
//        radius: units.gu(2)
//        color: "lightblue"
//        opacity: 0.5
//        z: 99999999999999999999

//        Label
//        {
//            text: "launch demo"
//        }

//        MouseArea
//        {
//            anchors.fill: parent
//            onClicked:
//            {
//                mainPageStack.push(tabs_demo);
//            }
//        }
//    }

    PageStack {
        id: mainPageStack
        Component.onCompleted: {
            DB.dropTables()
            push(todayPage)
            todayPage.refresh()
//            PopupUtils.open(popoverComponent, mainPageStack);
            push(tabs_demo);
        }
        anchors.fill: parent
        __showHeader: false

        TodayPage {
            id: todayPage
            // anchors.fill: parent // QTROS
            visible: false
            onRequestFeedListPage: mainPageStack.push(feedListPage)
        }

        FeedListPage {
            id: feedListPage
            visible: false
            anchors.fill: parent
            onFeedSelected: {
                if(selectedFeed != "") {
                    mainPageStack.push(selectedEntryListPageView)
                    selectedEntryListPage.feedLink = selectedFeed
                    var feed = DB.loadFeed(selectedFeed)
                    selectedEntryTab.title = feed.displayName
                } else {
                    mainPageStack.clear()
                    mainPageStack.push(todayPage)
                }
            }
            onFeedsReloaded: {
                todayPage.refresh()
            }
            onFeedDeleted: {
                todayPage.refresh()
            }
        }
        Page {
            anchors.fill: parent
            id: selectedEntryListPageView
            visible: false
            Tabs {
                anchors.fill: parent
                Tab {
                    id: selectedEntryTab
                    title: i18n.tr("Selected feed") // todo replace with feed name
                    page: EntryListPage {
                        anchors.fill: parent
                        id: selectedEntryListPage
                    }
                }
            }
        }
        SingleEntryPage {
            id: singleEntryPage
            visible: false
            anchors.fill: parent
        }

        //////////////////////////////////////////////////////////////////////     add by Joey Chan ----- 2013-04-17
        //////////////////////////////////////////////////////////////////////     my first demo

        Tabs {
            id: tabs_demo
            anchors.fill: parent
            visible: false

            // a property for judging list mode or mosaic mode
            property bool isListMode: false

            // First tab begins here
            Tab {
                objectName: "Tab1"

                title: i18n.tr("RSS Reader")
                clip: true

                                                   // main page for RSS feeds viewing
                page:
                    Page {
                    id: page_mosaic
                    anchors.margins: units.gu(2)

                    tools: ToolbarActions {
                        Action {
                            objectName: "action"

                            iconSource: Qt.resolvedUrl("avatar.png")
                            text: i18n.tr("Change mode")

                            onTriggered: {
                                tabs_demo.isListMode = tabs_demo.isListMode ? false : true ;    // switch mode for mosaic or list
                            }
                        }
//                        Action {
//                            id: popup
//                            objectName: "action1"

//                            iconSource: Qt.resolvedUrl("avatar.png")
//                            text: i18n.tr("popover")

//                            onTriggered: {
//                                PopupUtils.open(popoverComponent, popup.itemHint);
//                            }
//                        }
                    }

                    // ListView for RSS feeds
                    ListView
                    {
                        id: feed_view
                        //                    anchors.left: parent.left
                        //                    anchors.leftMargin: units.gu(1)
                        anchors.fill: parent
                        cacheBuffer: 90
                        spacing: units.gu(2)
                        contentHeight: tabs_demo.isListMode ? units.gu(7) * count : units.gu(37) * count
                        model: rssFeeds
                        delegate: rss_feed_delegate
                        //                    clip: true
                    }
                }

            }

        }

        // independent page for viewing one RSS feed
        RssFeedPage
        {
            id: feed_page
            visible: false
        }
    }

    // delegate for listview
    Component
    {
        id: rss_feed_delegate

        RssFeedDelegate
        {
            width: parent.width
            rss_url: feed
            isList: tabs_demo.isListMode

            ////////////////////////////////////////////       click an RSS item to push RssFeedPage to stack
            onItem_click:
            {
                feed_page.rssmodel_url = rss_model ;
                feed_page.rss_index = rss_index ;
                feed_page.rsstitle = rss_title ;
                mainPageStack.push(feed_page);
            }
        }
    }

    // RSS feeds example
    ListModel {
        id: rssFeeds

        ListElement { name: "Top Stories"; feed: "http://news.yahoo.com/rss/topstories" }
        ListElement { name: "World"; feed: "http://news.yahoo.com/rss/world" }
        ListElement { name: "Europe"; feed: "http://news.yahoo.com/rss/europe" }
        ListElement { name: "Oceania"; feed: "http://news.yahoo.com/rss/oceania" }
        ListElement { name: "U.S. National"; feed: "http://news.yahoo.com/rss/us" }
        ListElement { name: "Politics"; feed: "http://news.yahoo.com/rss/linux" }
        ListElement { name: "Business"; feed: "http://news.yahoo.com/rss/business" }
        ListElement { name: "Technology"; feed: "http://news.yahoo.com/rss/tech" }
        ListElement { name: "Entertainment"; feed: "http://news.yahoo.com/rss/entertainment" }
        ListElement { name: "Health"; feed: "http://news.yahoo.com/rss/health" }
        ListElement { name: "Science"; feed: "http://news.yahoo.com/rss/science" }
        ListElement { name: "Sports"; feed: "http://news.yahoo.com/rss/sports" }
    }

    // a popup to show options
    Component {
        id: popoverComponent

        Popover {
            id: popover
            z: 10

            Component.onCompleted: console.log("popup")

            Column {
                id: containerLayout
//                anchors.fill: parent
                anchors {
                    left: parent.left
                    top: parent.top
                    right: parent.right
                }

                ListItem.Standard {
                    text: "Hot"
//                    selected: articleList.filter == 'hot'
                    onClicked: {
//                        articleList.filter = 'hot'
                        PopupUtils.close(popover)
                    }
                }
                ListItem.Standard {
                    text: "New"
//                    selected: articleList.filter == 'new'
                    onClicked: {
//                        articleList.filter = 'new'
                        PopupUtils.close(popover)
                    }
                }

            }
        } // Popover
    } // Popover component
}
